Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2646)

Unified Diff: editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/error/CompileTimeErrorCode.java

Issue 14657012: Report CTEC.AMBIGUOUS_EXPORT (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Move implementation to ErrorVerifier Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/error/CompileTimeErrorCode.java
diff --git a/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/error/CompileTimeErrorCode.java b/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/error/CompileTimeErrorCode.java
index 38ca6b0a9845c52dea619b55048844271ee9ab4b..42e410952d52705e9220c599d45bb4a822c0e51e 100644
--- a/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/error/CompileTimeErrorCode.java
+++ b/editor/tools/plugins/com.google.dart.engine/src/com/google/dart/engine/error/CompileTimeErrorCode.java
@@ -26,8 +26,12 @@ public enum CompileTimeErrorCode implements ErrorCode {
* 14.2 Exports: It is a compile-time error if a name <i>N</i> is re-exported by a library
* <i>L</i> and <i>N</i> is introduced into the export namespace of <i>L</i> by more than one
* export.
+ *
+ * @param ambiguousElementName the name of the ambiguous element
+ * @param firstLibraryName the name of the first library that the type is found
+ * @param secondLibraryName the name of the second library that the type is found
*/
- AMBIGUOUS_EXPORT(""),
+ AMBIGUOUS_EXPORT("The element '%s' is defined in the libraries '%s' and '%s'"),
/**
* 14.1 Imports: If a name <i>N</i> is referenced by a library <i>L</i> and <i>N</i> is introduced
@@ -39,11 +43,11 @@ public enum CompileTimeErrorCode implements ErrorCode {
* <li>Otherwise, it is a compile-time error.
* </ol>
*
* @param ambiguousTypeName the name of the ambiguous type
* @param firstLibraryName the name of the first library that the type is found
* @param secondLibraryName the name of the second library that the type is found
*/
- AMBIGUOUS_IMPORT("The type '%s' is defined in the libraries '%s' and '%s'"),
+ AMBIGUOUS_IMPORT("The element '%s' is defined in the libraries '%s' and '%s'"),
/**
* 12.33 Argument Definition Test: It is a compile time error if <i>v</i> does not denote a formal
@@ -39,11 +43,11 @@ public enum CompileTimeErrorCode implements ErrorCode {
* </ol>
*
- * @param ambiguousTypeName the name of the ambiguous type
+ * @param ambiguousElementName the name of the ambiguous element
* @param firstLibraryName the name of the first library that the type is found
* @param secondLibraryName the name of the second library that the type is found

Powered by Google App Engine
This is Rietveld 408576698